@@ -187,8 +187,14 @@ class Database(object):
                     if constraint.name:
                         constraint.name = conv(constraint.name)
 
+            generated_indexes = set()
             for index in self.get_all_indexes():
-                index.name = conv(generate_valid_index_name(index, self.engine.dialect))
+                index.name = conv(
+                    generate_valid_index_name(
+                        index, self.engine.dialect, exclude=generated_indexes
+                    )
+                )
+                generated_indexes.add(index.name)
                 mysql_length = {}
 
                 if self.engine.dialect.name == "mysql":
@@ -344,13 +350,12 @@ class Database(object):
                 yield table.name, con.execute(count_query).scalar()
 
     def _name_for_scalar_relationship(self, base, local_cls, referred_cls, constraint):
-        name = referred_cls.__name__.lower()
         try:
-            column_name = list(constraint.columns)[0].name
-            name = column_name.strip("_id")
+            relationship_name = list(constraint.columns)[0].name.strip("_id")
+            assert relationship_name not in local_cls.__table__.columns
+            return relationship_name
         except:
-            pass
-        return name
+            return referred_cls.__name__.lower()
 
     def _name_for_collection_relationship(
         self, base, local_cls, referred_cls, constraint
